@@ -56,7 +56,7 @@ def create_logger():
         Setup the logging environment
     """
     log = logging.getLogger()  # root logger
-    log.setLevel(DEFAULT_LOG_LEVEL.upper())
+    set_global_loglevel(DEFAULT_LOG_LEVEL.upper())
     format_str = '%(asctime)s - %(levelname)-8s - %(message)s'
     date_format = '%Y-%m-%d %H:%M:%S'
     if HAVE_COLORLOG and os.isatty(2):
@@ -85,6 +85,23 @@ def cleanup_logger():
             logging.root.removeHandler(handler)
 
 
+def set_global_loglevel(level):
+    """
+        Configure the global log level.
+        Implemented as function to monkey-patch it out in tests.
+    """
+    logging.getLogger().setLevel(level)
+
+
+def register_signal_handlers(loop):
+    """
+        Register the signal handlers which should be handled by the
+        event loop. Implemented as function to monkey-patch it out in tests.
+    """
+    loop.add_signal_handler(signal.SIGTERM, interruption)
+    loop.add_signal_handler(signal.SIGINT, interruption)
+
+
 def interruption():
     """
         Gracefully cancel all tasks in the event loop
@@ -109,10 +126,15 @@ def termination():
 
 def shutdown_loop(loop):
     """
-        Waits for completion of the event loop
+        Waits for completion of the event loop but ignores any exceptions.
+        The tasks are either already cancelled or will be transitively
+        cancelled shortly. As this is the final cleanup, we cannot check for
+        exceptions as these might lead in an unclosed event loops.
     """
     pending = asyncio.all_tasks(loop)
-    loop.run_until_complete(asyncio.gather(*pending))
+    if len(pending):
+        logging.debug("Cleanup %d remaining tasks", len(pending))
+    loop.run_until_complete(asyncio.gather(*pending, return_exceptions=True))
     loop.close()
 
 
@@ -179,17 +201,13 @@ def kas(argv):
     args = parser.parse_args(argv)
 
     if args.log_level:
-        logging.getLogger().setLevel(args.log_level.upper())
+        set_global_loglevel(args.log_level.upper())
 
     logging.info('%s %s started', os.path.basename(sys.argv[0]), __version__)
 
     loop = asyncio.new_event_loop()
     asyncio.set_event_loop(loop)
-
-    loop.add_signal_handler(signal.SIGTERM, interruption)
-    # don't overwrite pytest's signal handler
-    if "PYTEST_CURRENT_TEST" not in os.environ:
-        loop.add_signal_handler(signal.SIGINT, interruption)
+    register_signal_handlers(loop)
 
     try:
         plugin_class = plugins.get(args.cmd)
