@@ -26,7 +26,7 @@
     referenced config files, expand includes and print a flattened yaml version
     of the configuration to stdout. This config is semantically identical to
     the input, but does not include any references to other configuration
-    files. The output of this command can be used to further analyse the build
+    files. The output of this command can be used to further analyze the build
     configuration.
 
     When running with ``--lock``, a locking spec is created which only contains
@@ -77,6 +77,9 @@ from kas.kasusererror import KasUserError, ArgsCombinationError
 __license__ = 'MIT'
 __copyright__ = 'Copyright (c) Siemens AG, 2022'
 
+LOCKFILE_VERSION_MIN = 14
+SCHEMA_VERSION_MIN = 7
+
 
 class OutputFormatError(KasUserError):
     def __init__(self, format):
@@ -171,7 +174,8 @@ class Dump(Checkout):
                             help='Output format (default: yaml)')
         parser.add_argument('--resolve-refs',
                             action='store_true',
-                            help='Replace floating refs with exact SHAs')
+                            help='Replace floating refs with exact SHAs. '
+                                 'Overrides are removed')
         parser.add_argument('--resolve-local',
                             action='store_true',
                             help='Add tracking information of root repo')
@@ -221,9 +225,9 @@ class Dump(Checkout):
 
         super().run(args)
         ctx = get_context()
-        schema_v = 14 if args.lock else 7
+        schema_v = LOCKFILE_VERSION_MIN if args.lock else SCHEMA_VERSION_MIN
         config_expanded = {'header': {'version': schema_v}} if args.lock \
-            else ctx.config.get_config()
+            else ctx.config.get_config(remove_includes=True)
         repos = ctx.config.repo_dict.items()
         output = IoTarget(target=sys.stdout, managed=False)
 
@@ -245,16 +249,15 @@ class Dump(Checkout):
             config_expanded['overrides'] = \
                 {'repos': {k: {'commit': r.revision} for k, r in repos}}
 
-        # includes are already expanded, delete the key
-        if 'includes' in config_expanded['header']:
-            del config_expanded['header']['includes']
-
         if args.resolve_refs and not args.lock:
             for k, r in _filter_enabled(repos):
                 if r.commit or r.branch or r.tag:
                     config_expanded['repos'][k]['commit'] = r.revision
                 elif r.refspec:
                     config_expanded['repos'][k]['refspec'] = r.revision
+            # as the refs are resolved, the overrides are redundant
+            if 'overrides' in config_expanded:
+                del config_expanded['overrides']
 
         if args.resolve_local:
             for k, r in _filter_local(repos):
