@@ -83,6 +83,14 @@ class PatchApplyError(KasUserError):
         super().__init__(msg)
 
 
+class RepoFetchError(KasUserError):
+    """
+    An error occurred during repo fetching
+    """
+    def __init__(self, repo, output):
+        super().__init__(f'Fetching of repo: "{repo.name}" failed: {output}')
+
+
 class Repo:
     """
         Represents a repository in the kas configuration.
@@ -273,6 +281,7 @@ class Repo:
                                'for local repositories.')
         if refspec is None:
             commit = repo_overrides.get('commit', commit)
+            branch = repo_overrides.get('branch', branch)
             if commit and get_context().update:
                 logging.warning(f'Update of "{name}" requested, but repo is '
                                 'pinned to a fixed commit. Not updating.')
@@ -362,7 +371,7 @@ class RepoImpl(Repo):
         """
 
         if self.operations_disabled:
-            return 0
+            return
 
         refdir = get_context().kas_repo_ref_dir
         sdir = os.path.join(refdir, self.qualified_name) if refdir else None
@@ -403,9 +412,12 @@ class RepoImpl(Repo):
         # take what came out of clone and stick to that forever
         if self.commit is None and self.tag is None and self.branch is None \
            and self.refspec is None:
-            return 0
+            return
 
-        if not get_context().update:
+        # check if we already have the commit. On update, check as well in case
+        # the commit is fixed, hence the repo must not be updated anyways
+        force_update = get_context().update
+        if not force_update or (force_update and self.commit):
             # Do commit/tag/branch/refspec exist in the current repository?
             (retc, output) = await run_cmd_async(self.contains_refspec_cmd(),
                                                  cwd=self.path,
@@ -423,9 +435,9 @@ class RepoImpl(Repo):
                     (_, output) = await run_cmd_async(
                         self.branch_contains_ref(), cwd=self.path, fail=False)
                     if output.strip():
-                        return retc
+                        return
                 else:
-                    return retc
+                    return
 
         # Try to fetch if commit/tag/branch/refspec is missing or if --update
         # argument was passed
@@ -433,11 +445,11 @@ class RepoImpl(Repo):
                                              cwd=self.path,
                                              fail=False)
         if retc:
-            logging.warning('Could not update repository %s: %s',
-                            self.name, output)
+            logging.error('Could not update repository %s: %s',
+                          self.name, output)
+            raise RepoFetchError(self, output)
         else:
             logging.info('Repository %s updated', self.name)
-        return 0
 
     def checkout(self):
         """
