@@ -31,7 +31,7 @@ fi
 
 mv newchangelog CHANGELOG.md
 sed -i "s,\(__version__ =\).*,\1 \'$NEW_VERSION\'," kas/__version__.py
-sed -i "s,\(KAS_IMAGE_VERSION_DEFAULT=\).*,\1\"$NEW_VERSION\"," kas-container
+sed -i "s,^\(KAS_CONTAINER_SCRIPT_VERSION=\).*,\1\"$NEW_VERSION\"," kas-container
 
 git add CHANGELOG.md
 git add kas/__version__.py
@@ -41,7 +41,7 @@ git commit -m "Release $NEW_VERSION"
 git tag -s -m "Release $NEW_VERSION" "$NEW_VERSION"
 git push --follow-tags
 
-python3 setup.py sdist
+python3 -m build --sdist
 twine upload -s -r pypi "dist/kas-$NEW_VERSION.tar.gz"
 
 authors=$(git shortlog -s "$OLD_VERSION".."$NEW_VERSION" | cut -c8- | paste -s -d, - | sed -e 's/,/, /g')
