@@ -31,6 +31,7 @@ import pytest
 from kas import kas
 from kas.libkas import TaskExecError, KasUserError, run_cmd
 from kas.attestation import file_digest_slow
+from kas.repos import RepoFetchError
 
 
 @pytest.mark.dirsfromenv
@@ -82,6 +83,21 @@ def test_checkout(monkeykas, tmpdir):
     assert not (kas_bd / 'downloads').exists()
     assert not (kas_bd / 'sstate-cache').exists()
 
+    # test re-fetching (remove commit as nothing is fetched otherwise)
+    with open('test.yml', 'r') as f:
+        yml = yaml.safe_load(f)
+    with open('test-no-commit.yml', 'w') as f:
+        del yml['repos']['kas_1.1']['commit']
+        yml['repos']['kas_1.1']['branch'] = 'master'
+        yaml.safe_dump(yml, f)
+    kas.kas(['checkout', '--update', 'test-no-commit.yml'])
+
+    with monkeykas.context() as mc:
+        from kas.repos import GitRepo
+        mc.setattr(GitRepo, "fetch_cmd", lambda _: ["false"])
+        with pytest.raises(RepoFetchError):
+            kas.kas(['checkout', '--update', 'test-no-commit.yml'])
+
 
 def test_invalid_checkout(monkeykas, tmpdir, capsys):
     tdir = str(tmpdir / 'test_commands')
@@ -315,6 +331,8 @@ def test_lockfile(monkeykas, tmpdir, capsys):
 
     # insert older commit into lockfile (kas post commit/branch introduction)
     test_commit = '226e92a7f30667326a63fd9812b8cc4a6184e398'
+    # a commit message between test_commit and HEAD
+    test_shortmsg = 'Release 4.8'
     lockspec['overrides']['repos']['externalrepo']['commit'] = test_commit
     with open('test.lock.yml', 'w') as f:
         yaml.safe_dump(lockspec, f)
@@ -326,7 +344,9 @@ def test_lockfile(monkeykas, tmpdir, capsys):
         == test_commit
 
     # update lockfile, check if repo is pinned to other commit
+    capsys.readouterr()
     kas.kas('dump --lock --inplace --update test.yml'.split())
+    assert test_shortmsg in capsys.readouterr().out
     with open('test.lock.yml', 'r') as f:
         lockspec = yaml.safe_load(f)
         assert lockspec['overrides']['repos']['externalrepo']['commit'] \
